@@ -1,14 +1,14 @@
 from khl import Message
 
-from khl.plugin.plugin_interface import PluginInterface
+from khldaemon.plugin.interface import PluginInterface, MessageInterface
 
 PLUGIN_METADATA = {
     'id': 'khl_plugin',
     'version': '1.0.0',
-    'name': 'KHL Plugin',
+    'name': 'KHLDaemon',
     'description': 'A khl.py builtin plugin',
     'author': 'DancingSnow',
-    'link': 'https://github.com/DancingSnow0517/khl.py/tree/plugin'
+    'link': 'https://github.com/DancingSnow0517/KHLDaemon'
 }
 
 
@@ -21,13 +21,13 @@ def on_load(interface: PluginInterface):
     @bot.command(name='help', prefixes=['!!'])
     async def help_msg(msg: Message):
         help_messages = ''
-        for i in interface.help_messages:
-            help_messages += f'[{i}] {interface.help_messages[i]}\n'
+        for i in interface.plugin_manager.help_messages:
+            help_messages += f'[{i}] {interface.plugin_manager.help_messages[i]}\n'
         await msg.reply(help_messages)
 
     @bot.command(name='khl', prefixes=['!!'])
     async def khl(msg: Message):
-        rt = f'当前已加载 {len(interface.plugin_Manager.plugins)} 个插件'
+        rt = f'当前已加载 {len(interface.plugin_manager.plugins)} 个插件'
         await msg.reply(rt)
 
 
@@ -35,5 +35,5 @@ def on_unload(interface: PluginInterface):
     pass
 
 
-async def on_message(msg: Message):
+async def on_message(interface: MessageInterface):
     pass
