@@ -1,4 +1,3 @@
-import contextlib
 import importlib
 
 from .meta import Meta
@@ -10,12 +9,18 @@ class Plugin:
         self.module = importlib.import_module(path)
         self.meta = Meta(self.module)
 
-        with contextlib.suppress(Exception):
+        try:
             self.on_load = self.module.on_load
-        with contextlib.suppress(Exception):
+        except AttributeError:
+            self.on_load = lambda interface: ...
+        try:
             self.on_unload = self.module.on_unload
-        with contextlib.suppress(Exception):
+        except AttributeError:
+            self.on_unload = lambda interface: ...
+        try:
             self.on_message = self.module.on_message
+        except AttributeError:
+            self.on_unload = lambda interface: ...
 
     def __str__(self) -> str:
         return self.meta.name
